Source: racksdb
Section: net
Priority: optional
Maintainer: HPCKit team <maintainers@hpck.it>
Homepage: https://github.com/rackslab/racksdb
Build-Depends:
 debhelper-compat (= 13),
 python3-all (>= 3.6),
 python3-setuptools,
 pybuild-plugin-pyproject,
 dh-python,
 asciidoctor,
 gir1.2-pango-1.0,
 libpango1.0-dev,
 npm,
 python3-cairo,
 python3-clustershell,
 python3-flask,
 python3-gi,
 python3-gi-cairo,
 python3-parameterized,
 python3-pytest,
 python3-requests-toolbelt,
 python3-rfl-build,
 python3-rfl-log,
 python3-yaml,
Standards-Version: 4.2.1

Package: python3-racksdb
Architecture: all
Section: python
Depends:
 ${misc:Depends},
 ${python3:Depends},
 gir1.2-pango-1.0,
 python3-gi-cairo,
Description: Python library for datacenter infrastructures database
 RacksDB is an open source solution to modelize your datacenters
 infrastructures in a simple YAML-based database to store information about the
 equipments in your datacenters provided with tools and library to request
 this database.
 This package provides RacksDB Python library.

Package: python3-racksdb-web
Architecture: all
Section: python
Depends:
 ${misc:Depends},
 ${python3:Depends},
 python3-racksdb (= ${binary:Version}),
 python3-flask,
 python3-requests-toolbelt,
Recommends:
 python3-flask-cors,
Description: Meta-package for datacenter infrastructures database web app
 RacksDB is an open source solution to modelize your datacenters
 infrastructures in a simple YAML-based database to store information about the
 equipments in your datacenters provided with tools and library to request
 this database.
 This package is a metapackage to install optional dependencies required by
 Python library for RacksDB web application.

Package: racksdb
Architecture: all
Section: admin
Depends:
 ${misc:Depends},
 python3-racksdb (= ${binary:Version}),
Description: CLI for datacenter infrastructures database
 RacksDB is an open source solution to modelize your datacenters
 infrastructures in a simple YAML-based database to store information about the
 equipments in your datacenters provided with tools and library to request
 this database.
 This package provides RacksDB CLI.

Package: racksdb-web
Architecture: all
Section: admin
Depends:
 ${misc:Depends},
 python3-racksdb-web (= ${binary:Version}),
Description: Web application with REST API for RacksDB
 RacksDB is an open source solution to modelize your datacenters
 infrastructures in a simple YAML-based database to store information about the
 equipments in your datacenters provided with tools and library to request
 this database.
 This package provides RacksDB HTTP REST API server.
